@@ -110,10 +110,16 @@ class SoundName(Enum):
     BOING = "Boing"
 
 
+class DeviceViewStyle(Enum):
+    """DeciveView Styles"""
+    BASIC = "BASIC"
+    BORDERS = "BORDERS"
+
+
 class ColorPickerStyle(Enum):
     """Picker styles"""
     WHEEL = "Wheel"
-    SPECTRUM = "SPectrum"
+    SPECTRUM = "Spectrum"
 
 
 class LabelStyle(Enum):
@@ -157,7 +163,7 @@ class ButtonState(Enum):
 class Keyboard(Enum):
     """Keyboards"""
     NONE = "NONE"
-    ALL_CHARS = "ALL"
+    ALL = "ALL"
     NUMERIC = "NUM"
     DATE = "DATE"
     TIME = "TIME"
@@ -183,9 +189,9 @@ class TextAlignment(Enum):
     RIGHT = "right"
 
 
-class SliderBarType(Enum):
+class SliderBarStyle(Enum):
     """Slider bar types"""
-    SEGMENTED = "seg"
+    SEG = "seg"
     SOLID = "solid"
 
 
