@@ -190,7 +190,7 @@ class TimeGraph(Control):
         -------
         TimeGraph
         """
-        return cls(
+        tmp_cls = cls(
             cfg_dict["controlID"],
             cfg_dict["title"],
             _get_title_position(cfg_dict["titlePosition"]),
@@ -200,6 +200,8 @@ class TimeGraph(Control):
             cfg_dict["yAxisNumBars"],
             ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
         )
+        tmp_cls.parent_id = cfg_dict["parentID"]
+        return tmp_cls
 
     def add_line(self, line_id: str, gline: TimeGraphLine):
         """Add a line to the TimeGraph
